import {Injectable} from '@angular/core';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {HttpErrorService} from 'src/app/ErrorComponents/http-error.service';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs';
import {StudentResponseDao} from '../dao/student-response.dao';
import {environment} from '../../environments/environment';

const httpOptions = {
  headers: new HttpHeaders({
    'Content-Type':  'application/json'
  })
};

@Injectable()
export class StudentInfoService {

  constructor(private http$: HttpClient, private errorService: HttpErrorService) {
  }

  public getStudentClasses(username: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getStudentClasses', {username: username}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getOpenPapers(username: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getOpenPapers', {username: username}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getSubmittedPapers(username: String, classCode: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getSubmittedClassPapers', {username: username, classCode: classCode}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getPaperQuestions(username: String, paperId: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getPaperQuestions', {paperId: paperId}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public getStudentAnswers(username: String, paperId: String): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/getStudentAnswers', {username: username, paperId: paperId}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public saveDraft(answers: StudentResponseDao[]): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/saveDraft', {responses: answers}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }

  public submitResponse(answers: StudentResponseDao[]): Observable<String | Object> {
    return this.http$.post(environment.apiUrl + '/submitResponse', {responses: answers}, httpOptions).pipe(
      catchError(this.errorService.handleError)
    );
  }
}
